PCB Environment: dsn::Structure Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
dsn::Structure Struct Reference

## Public Member Functions
std::string | str () const

## Data Fields
std::vector< Layer * > | copper_layers
std::vector< Layer > | layers
Path | boundary
std::map< std::string, std::string > | via
std::map< std::string, double > | width
std::map< std::string, double > | clearance

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSN.hpp